@@ -1,5 +1,5 @@
 package CPAN::Testers::API::Controller::Release;
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 # ABSTRACT: API for test reports collected by CPAN release
 
 #pod =head1 DESCRIPTION
@@ -41,7 +41,6 @@ use CPAN::Testers::API::Base;
 #pod         {
 #pod             "dist": "My-Dist",
 #pod             "version": "1.000",
-#pod             "author": "PREACTION",
 #pod             "pass": 34,
 #pod             "fail": 2,
 #pod             "na": 1,
@@ -53,18 +52,34 @@ use CPAN::Testers::API::Base;
 #pod C<dist> key in the stash), by author (with the C<author> key in the
 #pod stash), and by date (with the C<since> query parameter).
 #pod
+#pod Release data contains a summary of the pass, fail, na, and unknown test
+#pod results created by stable Perls. Development Perls (odd-numbered 5.XX
+#pod releases) are not included.
+#pod
 #pod =cut
 
 sub release( $c ) {
     $c->openapi->valid_input or return;
 
     my $rs = $c->schema->resultset( 'Release' );
-    # Only get hashrefs out
-    $rs = $rs->search( {}, {
-        result_class => 'DBIx::Class::ResultClass::HashRefInflator',
-    } );
+    $rs = $rs->search(
+        {
+            perlmat => 1, # only stable perls
+            patched => 1, # not patched perls
+        },
+        {
+            columns => [qw( dist version pass fail na unknown )],
+            # Only get hashrefs out
+            result_class => 'DBIx::Class::ResultClass::HashRefInflator',
+        }
+    );
 
-    if ( my $since = $c->validation->param( 'since' ) ) {
+    # Only allow "since" for "dist" and "author" because the query can
+    # not be optimized to return in a reasonable time.
+    if ( my $since = $c->param( 'since' ) ) {
+        unless ( $c->validation->param( 'dist' ) || $c->validation->param( 'author' ) ) {
+            return $c->render_error( 400 => '"since" parameter not allowed' );
+        }
         $rs = $rs->since( $since );
     }
 
@@ -73,31 +88,13 @@ sub release( $c ) {
         $rs = $rs->by_dist( $dist );
         @results = $rs->all;
         if ( !@results ) {
-            return $c->render(
-                status => 404,
-                openapi => {
-                    errors => [
-                        {
-                            message => sprintf( 'Distribution "%s" not found', $dist ),
-                        },
-                    ],
-                },
-            );
+            return $c->render_error( 404, sprintf 'Distribution "%s" not found', $dist );
         }
     }
     elsif ( my $author = $c->validation->param( 'author' ) ) {
         @results = $rs->by_author( $author )->all;
         if ( !@results ) {
-            return $c->render(
-                status => 404,
-                openapi => {
-                    errors => [
-                        {
-                            message => sprintf( 'Author "%s" not found', $author ),
-                        },
-                    ],
-                },
-            );
+            return $c->render_error( 404, sprintf 'Author "%s" not found', $author );
         }
     }
     else {
@@ -121,7 +118,7 @@ CPAN::Testers::API::Controller::Release - API for test reports collected by CPAN
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
@@ -149,7 +146,6 @@ has for each version released, this is the best API.
         {
             "dist": "My-Dist",
             "version": "1.000",
-            "author": "PREACTION",
             "pass": 34,
             "fail": 2,
             "na": 1,
@@ -161,6 +157,10 @@ Get release data. Results can be limited by distribution (with the
 C<dist> key in the stash), by author (with the C<author> key in the
 stash), and by date (with the C<since> query parameter).
 
+Release data contains a summary of the pass, fail, na, and unknown test
+results created by stable Perls. Development Perls (odd-numbered 5.XX
+releases) are not included.
+
 =head1 SEE ALSO
 
 =over
